@@ -18,7 +18,7 @@
 */
 
 /**
- * \author UTB Relativity Group; contact whelan@phys.utb.edu
+ * \author UTB Relativity Group; contact john.whelan@ligo.org
  * \addtogroup StochasticOptimalFilter_c
  *
  * \brief Calculates the values of the optimal filter function for the standard cross-correlation statistic.
@@ -114,9 +114,9 @@
  * ### Uses ###
  *
  * \code
- * LALUnitMultiply()
- * LALUnitRaise()
- * LALUnitCompare()
+ * XLALUnitMultiply()
+ * XLALUnitRaiseRAT4()
+ * XLALUnitCompare()
  * \endcode
  *
  * ### Notes ###
@@ -191,7 +191,6 @@ LALStochasticOptimalFilterCal(
   UINT4 length;
 
   RAT4 power;
-  LALUnitPair unitPair;
   LALUnit tmpUnit1, tmpUnit2, checkUnit;
 
   /* initialize status pointer */
@@ -386,51 +385,52 @@ LALStochasticOptimalFilterCal(
 
   /* Now set tmpUnit2 to dims of H0^-2 */
   power.numerator = -2;
-  TRY(LALUnitRaise(status->statusPtr, &tmpUnit2, &tmpUnit1, &power), status);
+  if (XLALUnitRaiseRAT4(&tmpUnit2, &tmpUnit1, &power) == NULL) {
+    ABORTXLAL(status);
+  }
 
-  unitPair.unitOne = &(input->omegaGW->sampleUnits);
-  unitPair.unitTwo = &tmpUnit2;
-
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit1, &unitPair), status);
+  if (XLALUnitMultiply(&tmpUnit1, &(input->omegaGW->sampleUnits), &tmpUnit2) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* Now tmpUnit1 has units of Omega/H0^2 */
 
   /* Now we need to set the Optimal Filter Units equal to the units of
    * lambda*mygamma*Omega*f^-3*P1W^-1*P2W^-1) */
 
-  unitPair.unitOne = &(input->calibratedInverseNoisePSD1->sampleUnits);
-  unitPair.unitTwo = &(input->calibratedInverseNoisePSD2->sampleUnits);
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit1, &unitPair) , status);
+  if (XLALUnitMultiply(&tmpUnit1, &(input->calibratedInverseNoisePSD1->sampleUnits), &(input->calibratedInverseNoisePSD2->sampleUnits)) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit1 now holds the units of P1W^-1*P2W^-1 */
 
   power.numerator = -3;
-  TRY(LALUnitRaise(status->statusPtr, &tmpUnit2, &lalHertzUnit, \
-        &power), status);
+  if (XLALUnitRaiseRAT4(&tmpUnit2, &lalHertzUnit, &power) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit2 now holds the units of f^-3 */
 
-  unitPair.unitOne = &tmpUnit1;
-  unitPair.unitTwo = &tmpUnit2;
-  TRY(LALUnitMultiply(status->statusPtr, &checkUnit, &unitPair), status);
+  if (XLALUnitMultiply(&checkUnit, &tmpUnit1, &tmpUnit2) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* checkUnit now holds the units of f^-3*P1HW^-1*P2HW^-1) */
-  unitPair.unitOne = &checkUnit;
-  unitPair.unitTwo = &(input->omegaGW->sampleUnits);
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit1, &unitPair), status);
+  if (XLALUnitMultiply(&tmpUnit1, &checkUnit, &(input->omegaGW->sampleUnits)) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit1 now holds units of Omega*f^-3*P1W^-1*P2W^-1) */
 
-  unitPair.unitOne = &tmpUnit1;
-  unitPair.unitTwo = &(input->overlapReductionFunction->sampleUnits);
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit2, &unitPair), status);
+  if (XLALUnitMultiply(&tmpUnit2, &tmpUnit1, &(input->overlapReductionFunction->sampleUnits)) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit2 now holds units of mygamma*Omega*f^-3*P1W^-1*P2W^-1) */
 
-  unitPair.unitOne = &(lambda->units);
-  unitPair.unitTwo = &tmpUnit2;
-  TRY(LALUnitMultiply(status->statusPtr, &(optimalFilter->sampleUnits), \
-        &unitPair), status );
+  if (XLALUnitMultiply(&(optimalFilter->sampleUnits), &(lambda->units), &tmpUnit2) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* Done with unit manipulation */
 
@@ -486,7 +486,6 @@ LALStochasticOptimalFilter(
   UINT4 length;
 
   RAT4 power;
-  LALUnitPair unitPair;
   LALUnit tmpUnit1, tmpUnit2, checkUnit;
 
   /* initialize status pointer */
@@ -681,51 +680,52 @@ LALStochasticOptimalFilter(
 
   /* Now set tmpUnit2 to dims of H0^-2 */
   power.numerator = -2;
-  TRY(LALUnitRaise(status->statusPtr, &tmpUnit2, &tmpUnit1, &power), status);
+  if (XLALUnitRaiseRAT4(&tmpUnit2, &tmpUnit1, &power) == NULL) {
+    ABORTXLAL(status);
+  }
 
-  unitPair.unitOne = &(input->omegaGW->sampleUnits);
-  unitPair.unitTwo = &tmpUnit2;
-
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit1, &unitPair), status);
+  if (XLALUnitMultiply(&tmpUnit1, &(input->omegaGW->sampleUnits), &tmpUnit2) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* Now tmpUnit1 has units of Omega/H0^2 */
 
   /* Now we need to set the Optimal Filter Units equal to the units of */
   /* lambda*mygamma*Omega*f^-3*P1HW^-1*P2HW^-1) */
 
-  unitPair.unitOne = &(input->halfCalibratedInverseNoisePSD1->sampleUnits);
-  unitPair.unitTwo = &(input->halfCalibratedInverseNoisePSD2->sampleUnits);
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit1, &unitPair) , status);
+  if (XLALUnitMultiply(&tmpUnit1, &(input->halfCalibratedInverseNoisePSD1->sampleUnits), &(input->halfCalibratedInverseNoisePSD2->sampleUnits)) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit1 now holds the units of P1HW^-1*P2HW^-1 */
 
   power.numerator = -3;
-  TRY(LALUnitRaise(status->statusPtr, &tmpUnit2, &lalHertzUnit, &power), \
-      status);
+  if (XLALUnitRaiseRAT4(&tmpUnit2, &lalHertzUnit, &power) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit2 now holds the units of f^-3 */
 
-  unitPair.unitOne = &tmpUnit1;
-  unitPair.unitTwo = &tmpUnit2;
-  TRY(LALUnitMultiply(status->statusPtr, &checkUnit, &unitPair), status);
+  if (XLALUnitMultiply(&checkUnit, &tmpUnit1, &tmpUnit2) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* checkUnit now holds the units of f^-3*P1HW^-1*P2HW^-1) */
-  unitPair.unitOne = &checkUnit;
-  unitPair.unitTwo = &(input->omegaGW->sampleUnits);
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit1, &unitPair), status);
+  if (XLALUnitMultiply(&tmpUnit1, &checkUnit, &(input->omegaGW->sampleUnits)) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit1 now holds units of Omega*f^-3*P1HW^-1*P2HW^-1) */
 
-  unitPair.unitOne = &tmpUnit1;
-  unitPair.unitTwo = &(input->overlapReductionFunction->sampleUnits);
-  TRY(LALUnitMultiply(status->statusPtr, &tmpUnit2, &unitPair), status);
+  if (XLALUnitMultiply(&tmpUnit2, &tmpUnit1, &(input->overlapReductionFunction->sampleUnits)) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* tmpUnit2 now holds units of mygamma*Omega*f^-3*P1HW^-1*P2HW^-1) */
 
-  unitPair.unitOne = &(lambda->units);
-  unitPair.unitTwo = &tmpUnit2;
-  TRY(LALUnitMultiply(status->statusPtr, &(optimalFilter->sampleUnits), \
-        &unitPair), status);
+  if (XLALUnitMultiply(&(optimalFilter->sampleUnits), &(lambda->units), &tmpUnit2) == NULL) {
+    ABORTXLAL(status);
+  }
 
   /* Done with unit manipulation */
 
