@@ -18,7 +18,7 @@
 */
 
 /**
- * \author UTB Relativity Group; contact whelan@phys.utb.edu
+ * \author UTB Relativity Group; contact john.whelan@ligo.org
  * \file
  * \ingroup ZeroPadAndFFT_c
  *
@@ -95,13 +95,14 @@
  * LALCHARDestroyVector()
  * LALCreateForwardRealFFTPlan()
  * LALDestroyRealFFTPlan()
- * LALUnitAsString()
- * LALUnitCompare()
+ * XLALUnitAsString()
+ * XLALUnitCompare()
  * getopt()
  * printf()
  * fprintf()
  * freopen()
  * fabs()
+ * fabsf()
  * \endcode
  *
  * ### Notes ###
@@ -228,10 +229,9 @@ main( int argc, char *argv[] )
    COMPLEX8TimeSeries             goodInput;
    COMPLEX8FrequencySeries        goodOutput;
 
-   BOOLEAN                result;
-   LALUnitPair            unitPair;
+   int                    result;
    LALUnit                expectedUnit;
-   CHARVector             *unitString;
+   CHAR                   unitString[LALUnitTextSize];
 
    CZeroPadAndFFTParameters   goodParams;
 
@@ -571,55 +571,20 @@ main( int argc, char *argv[] )
    expectedUnit = lalDimensionlessUnit;
    expectedUnit.unitNumerator[LALUnitIndexADCCount] = 1;
    expectedUnit.unitNumerator[LALUnitIndexSecond] = 1;
-   unitPair.unitOne = &expectedUnit;
-   unitPair.unitTwo = &(goodOutput.sampleUnits);
-   LALUnitCompare(&status, &result, &unitPair);
-   if ( ( code = CheckStatus( &status, 0 , "",
-			      CZEROPADANDFFTTESTC_EFLS,
-			      CZEROPADANDFFTTESTC_MSGEFLS ) ) )
-   {
-     return code;
-   }
-
+   result = XLALUnitCompare(&expectedUnit, &(goodOutput.sampleUnits));
    if (optVerbose)
    {
-     unitString = NULL;
-     LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       CZEROPADANDFFTTESTC_EFLS,
-			       CZEROPADANDFFTTESTC_MSGEFLS) ) )
-     {
-       return code;
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodOutput.sampleUnits)) == NULL ) {
+       return CZEROPADANDFFTTESTC_EFLS;
      }
-
-     LALUnitAsString( &status, unitString, unitPair.unitTwo );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       CZEROPADANDFFTTESTC_EFLS,
-			       CZEROPADANDFFTTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "Units are \"%s\", ", unitString->data );
-
-     LALUnitAsString( &status, unitString, unitPair.unitOne );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       CZEROPADANDFFTTESTC_EFLS,
-			       CZEROPADANDFFTTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "should be \"%s\"\n", unitString->data );
-
-     LALCHARDestroyVector(&status, &unitString);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       CZEROPADANDFFTTESTC_EFLS,
-			       CZEROPADANDFFTTESTC_MSGEFLS) ) )
-     {
-       return code;
+     printf( "Units are \"%s\", ", unitString );
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &expectedUnit) == NULL ) {
+       return CZEROPADANDFFTTESTC_EFLS;
      }
+     printf( "should be \"%s\"\n", unitString );
    }
 
-   if (!result)
+   if (result != 0)
    {
      printf("  FAIL: Valid data test #1\n");
      if (optVerbose)
@@ -641,9 +606,9 @@ main( int argc, char *argv[] )
               f, crealf(goodOutput.data->data[i]), cimagf(goodOutput.data->data[i]),
               crealf(expectedOutputDataData[i]), cimagf(expectedOutputDataData[i]));
      }
-     if (fabs(crealf(goodOutput.data->data[i]) - crealf(expectedOutputDataData[i]))
+     if (fabsf(crealf(goodOutput.data->data[i]) - crealf(expectedOutputDataData[i]))
          /* / expectedOutputDataData[0].re */> CZEROPADANDFFTTESTC_TOL
-         || fabs(cimagf(goodOutput.data->data[i]) - cimagf(expectedOutputDataData[i]))
+         || fabsf(cimagf(goodOutput.data->data[i]) - cimagf(expectedOutputDataData[i]))
          /* / expectedOutputDataData[0].re */> CZEROPADANDFFTTESTC_TOL)
      {
        printf("  FAIL: Valid data test\n");
