@@ -106,9 +106,11 @@
  * LALCReadFrequencySeries()
  * LALSPrintFrequencySeries()
  * LALCPrintFrequencySeries()
- * LALUnitAsString()
- * LALUnitCompare()
+ * XLALUnitAsString()
+ * XLALUnitCompare()
  * LALCheckMemoryLeaks()
+ * fabs()
+ * fabsf()
  * \endcode
  *
  * ### Notes ###
@@ -212,11 +214,10 @@ int main(int argc, char *argv[])
   REAL4      expectedReal;
   REAL4      expectedImag;
 
-  LALUnitPair              unitPair;
   LALUnit                  expectedUnit;
-  BOOLEAN                  result;
+  int                      result;
 
-  CHARVector               *unitString = NULL;
+  CHAR                     unitString[LALUnitTextSize];
 
 
   ParseOptions (argc, argv);
@@ -746,54 +747,20 @@ int main(int argc, char *argv[])
    expectedUnit.unitNumerator[LALUnitIndexADCCount] = -1;
    expectedUnit.unitNumerator[LALUnitIndexStrain] = -1;
    expectedUnit.unitNumerator[LALUnitIndexSecond] = -1;
-   unitPair.unitOne = &expectedUnit;
-   unitPair.unitTwo = &(hwInvNoise.sampleUnits);
-   LALUnitCompare(&status, &result, &unitPair);
-   if ( ( code = CheckStatus(&status, 0 , "",
-			     STOCHASTICINVERSENOISETESTC_EFLS,
-			     STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-   {
-     return code;
-   }
-
+   result = XLALUnitCompare(&expectedUnit, &(hwInvNoise.sampleUnits));
    if (optVerbose)
    {
-     LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       STOCHASTICINVERSENOISETESTC_EFLS,
-			       STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-     {
-       return code;
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(hwInvNoise.sampleUnits)) == NULL ) {
+       return STOCHASTICINVERSENOISETESTC_EFLS;
      }
-
-     LALUnitAsString( &status, unitString, unitPair.unitTwo );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       STOCHASTICINVERSENOISETESTC_EFLS,
-			       STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "Units of 1/PHW(f) are \"%s\", ", unitString->data );
-
-     LALUnitAsString( &status, unitString, unitPair.unitOne );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       STOCHASTICINVERSENOISETESTC_EFLS,
-			       STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "should be \"%s\"\n", unitString->data );
-
-     LALCHARDestroyVector(&status, &unitString);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       STOCHASTICINVERSENOISETESTC_EFLS,
-			       STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-     {
-       return code;
+     printf( "Units are \"%s\", ", unitString );
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &expectedUnit) == NULL ) {
+       return STOCHASTICINVERSENOISETESTC_EFLS;
      }
+     printf( "should be \"%s\"\n", unitString );
    }
 
-   if (!result)
+   if (result != 0)
    {
      printf("  FAIL: Valid data test #1\n");
      if (optVerbose)
@@ -810,8 +777,8 @@ int main(int argc, char *argv[])
      printf("1/PHW(0)=%g + %g i, should be 0\n",
             crealf(hwInvNoise.data->data[0]), cimagf(hwInvNoise.data->data[0]));
    }
-   if ( fabs(crealf(hwInvNoise.data->data[0])) > STOCHASTICINVERSENOISETESTC_TOL
-        || fabs(cimagf(hwInvNoise.data->data[0]))
+   if ( fabsf(crealf(hwInvNoise.data->data[0])) > STOCHASTICINVERSENOISETESTC_TOL
+        || fabsf(cimagf(hwInvNoise.data->data[0]))
 	> STOCHASTICINVERSENOISETESTC_TOL )
    {
      printf("  FAIL: Valid data test\n");
@@ -833,9 +800,9 @@ int main(int argc, char *argv[])
 	     f, crealf(hwInvNoise.data->data[i]), cimagf(hwInvNoise.data->data[i]),
 	     expectedReal, expectedImag);
     }
-    if (fabs(crealf(hwInvNoise.data->data[i]) - expectedReal)/expectedReal
+    if (fabsf(crealf(hwInvNoise.data->data[i]) - expectedReal)/expectedReal
 	> STOCHASTICINVERSENOISETESTC_TOL
-	|| fabs(cimagf(hwInvNoise.data->data[i]) - expectedImag)/expectedImag
+	|| fabsf(cimagf(hwInvNoise.data->data[i]) - expectedImag)/expectedImag
 	> STOCHASTICINVERSENOISETESTC_TOL)
     {
       printf("  FAIL: Valid data test\n");
@@ -890,54 +857,20 @@ int main(int argc, char *argv[])
   expectedUnit = lalDimensionlessUnit;
   expectedUnit.unitNumerator[LALUnitIndexStrain] = -2;
   expectedUnit.unitNumerator[LALUnitIndexSecond] = -1;
-  unitPair.unitOne = &expectedUnit;
-  unitPair.unitTwo = &(invNoise.sampleUnits);
-  LALUnitCompare(&status, &result, &unitPair);
-  if ( ( code = CheckStatus(&status, 0 , "",
-			    STOCHASTICINVERSENOISETESTC_EFLS,
-			    STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-  {
-    return code;
-  }
-
+  result = XLALUnitCompare(&expectedUnit, &(invNoise.sampleUnits));
   if (optVerbose)
   {
-    LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-    if ( ( code = CheckStatus(&status, 0 , "",
-			      STOCHASTICINVERSENOISETESTC_EFLS,
-			      STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-    {
-      return code;
+    if ( XLALUnitAsString( unitString, LALUnitTextSize, &(invNoise.sampleUnits)) == NULL ) {
+      return STOCHASTICINVERSENOISETESTC_EFLS;
     }
-
-    LALUnitAsString( &status, unitString, unitPair.unitTwo );
-  if ( ( code = CheckStatus(&status, 0 , "",
-			    STOCHASTICINVERSENOISETESTC_EFLS,
-			    STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-    {
-      return code;
-    }
-    printf( "Units of 1/P(f) are \"%s\", ", unitString->data );
-
-    LALUnitAsString( &status, unitString, unitPair.unitOne );
-  if ( ( code = CheckStatus(&status, 0 , "",
-			    STOCHASTICINVERSENOISETESTC_EFLS,
-			    STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-    {
-      return code;
-    }
-    printf( "should be \"%s\"\n", unitString->data );
-
-    LALCHARDestroyVector(&status, &unitString);
-  if ( ( code = CheckStatus(&status, 0 , "",
-			    STOCHASTICINVERSENOISETESTC_EFLS,
-			    STOCHASTICINVERSENOISETESTC_MSGEFLS) ) )
-    {
-      return code;
+    printf( "Units are \"%s\", ", unitString );
+    if ( XLALUnitAsString( unitString, LALUnitTextSize, &expectedUnit) == NULL ) {
+      return STOCHASTICINVERSENOISETESTC_EFLS;
     }
+    printf( "should be \"%s\"\n", unitString );
   }
 
-  if (!result)
+  if (result != 0)
   {
     printf("  FAIL: Valid data test #1\n");
     if (optVerbose)
@@ -954,7 +887,7 @@ int main(int argc, char *argv[])
      printf("1/P(0)=%g, should be 0\n",
             invNoise.data->data[0]);
    }
-   if ( fabs(invNoise.data->data[0]) > STOCHASTICINVERSENOISETESTC_TOL )
+   if ( fabsf(invNoise.data->data[0]) > STOCHASTICINVERSENOISETESTC_TOL )
    {
      printf("  FAIL: Valid data test\n");
      if (optVerbose)
@@ -973,7 +906,7 @@ int main(int argc, char *argv[])
       printf("1/P(%f Hz)=%g, should be %g\n",
 	     f, invNoise.data->data[i], expectedReal);
     }
-    if ( fabs(invNoise.data->data[i] - expectedReal)/expectedReal
+    if ( fabsf(invNoise.data->data[i] - expectedReal)/expectedReal
 	 > STOCHASTICINVERSENOISETESTC_TOL )
     {
       printf("  FAIL: Valid data test\n");
