@@ -18,7 +18,7 @@
 */
 
 /**
- * \author UTB Relativity Group; contact whelan@phys.utb.edu
+ * \author UTB Relativity Group; contact john.whelan@ligo.org
  * \file
  * \ingroup StochasticOptimalFilter_c
  *
@@ -125,13 +125,14 @@
  * LALCDestroyVector()
  * LALCHARCreateVector()
  * LALCHARDestroyVector()
- * LALUnitAsString()
- * LALUnitCompare()
+ * XLALUnitAsString()
+ * XLALUnitCompare()
  * getopt()
  * printf()
  * fprintf()
  * freopen()
  * fabs()
+ * fabsf()
  * \endcode
  *
  * ### Notes ###
@@ -248,11 +249,9 @@ int main(int argc, char *argv[])
   REAL8      muTest;  /*refers to the calculated mu to test normalization*/
   REAL8      testNum;     /*temporary value used to check optimal output */
 
-  LALUnitPair              unitPair;
-  LALUnit                  expectedUnit;
-  BOOLEAN                  result;
-
-  CHARVector               *unitString = NULL;
+  int                    result;
+  LALUnit                expectedUnit;
+  CHAR                   unitString[LALUnitTextSize];
 
   REAL4WithUnits           lambda;
 
@@ -968,54 +967,20 @@ int main(int argc, char *argv[])
 
   expectedUnit = lalDimensionlessUnit;
   expectedUnit.unitNumerator[LALUnitIndexADCCount] = -2;
-  unitPair.unitOne = &expectedUnit;
-  unitPair.unitTwo = &(optimal.sampleUnits);
-  LALUnitCompare(&status, &result, &unitPair);
-  if ( ( code = CheckStatus(&status, 0 , "",
-                            STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                            STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-  {
-    return code;
-  }
-
+  result = XLALUnitCompare(&expectedUnit, &(optimal.sampleUnits));
   if (optVerbose)
   {
-    LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
+    if ( XLALUnitAsString( unitString, LALUnitTextSize, &(optimal.sampleUnits)) == NULL ) {
+      return STOCHASTICOPTIMALFILTERTESTC_EFLS;
     }
-
-    LALUnitAsString( &status, unitString, unitPair.unitTwo );
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
-    }
-    printf( "Units are \"%s\", ", unitString->data );
-
-    LALUnitAsString( &status, unitString, unitPair.unitOne );
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
-    }
-    printf( "should be \"%s\"\n", unitString->data );
-
-    LALCHARDestroyVector(&status, &unitString);
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
+    printf( "Units are \"%s\", ", unitString );
+    if ( XLALUnitAsString( unitString, LALUnitTextSize, &expectedUnit) == NULL ) {
+      return STOCHASTICOPTIMALFILTERTESTC_EFLS;
     }
+    printf( "should be \"%s\"\n", unitString );
   }
 
-  if (!result)
+  if (result != 0)
   {
     printf("  FAIL: Valid data test #1\n");
     if (optVerbose)
@@ -1032,8 +997,8 @@ int main(int argc, char *argv[])
     printf("Q(0)=%g + %g i, should be 0\n",
            crealf(optimal.data->data[0]), cimagf(optimal.data->data[0]));
   }
-  if ( fabs(crealf(optimal.data->data[0])) > STOCHASTICOPTIMALFILTERTESTC_TOL
-       || fabs(cimagf(optimal.data->data[0]))
+  if ( fabsf(crealf(optimal.data->data[0])) > STOCHASTICOPTIMALFILTERTESTC_TOL
+       || fabsf(cimagf(optimal.data->data[0]))
        > STOCHASTICOPTIMALFILTERTESTC_TOL )
   {
     printf("  FAIL: Valid data test #1\n");
@@ -1062,7 +1027,7 @@ int main(int argc, char *argv[])
     if (fabs(crealf(optimal.data->data[i])/crealf(optimal.data->data[1])
              - testNum)/testNum
         > STOCHASTICOPTIMALFILTERTESTC_TOL
-        || fabs(cimagf(optimal.data->data[i])/crealf(optimal.data->data[1]))
+        || fabsf(cimagf(optimal.data->data[i])/crealf(optimal.data->data[1]))
         > STOCHASTICOPTIMALFILTERTESTC_TOL)
     {
       printf("  FAIL: Valid data test #1\n");
@@ -1183,54 +1148,21 @@ int main(int argc, char *argv[])
   /* check output units */
   expectedUnit = lalDimensionlessUnit;
   expectedUnit.unitNumerator[LALUnitIndexADCCount] = -2;
-  unitPair.unitOne = &expectedUnit;
-  unitPair.unitTwo = &(optimal.sampleUnits);
-  LALUnitCompare(&status, &result, &unitPair);
-  if ( ( code = CheckStatus(&status, 0 , "",
-                            STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                            STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-  {
-    return code;
-  }
+  result = XLALUnitCompare(&expectedUnit, &(optimal.sampleUnits));
 
   if (optVerbose)
   {
-    LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
+    if ( XLALUnitAsString( unitString, LALUnitTextSize, &(optimal.sampleUnits)) == NULL ) {
+      return STOCHASTICOPTIMALFILTERTESTC_EFLS;
     }
-
-    LALUnitAsString( &status, unitString, unitPair.unitTwo );
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
-    }
-    printf( "Units are \"%s\", ", unitString->data );
-
-    LALUnitAsString( &status, unitString, unitPair.unitOne );
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
-    }
-    printf( "should be \"%s\"\n", unitString->data );
-
-    LALCHARDestroyVector(&status, &unitString);
-    if ( ( code = CheckStatus(&status, 0 , "",
-                              STOCHASTICOPTIMALFILTERTESTC_EFLS,
-                              STOCHASTICOPTIMALFILTERTESTC_MSGEFLS) ) )
-    {
-      return code;
+    printf( "Units are \"%s\", ", unitString );
+    if ( XLALUnitAsString( unitString, LALUnitTextSize, &expectedUnit) == NULL ) {
+      return STOCHASTICOPTIMALFILTERTESTC_EFLS;
     }
+    printf( "should be \"%s\"\n", unitString );
   }
 
-  if (!result)
+  if (result != 0)
   {
     printf("  FAIL: Valid data test #2\n");
     if (optVerbose)
@@ -1247,8 +1179,8 @@ int main(int argc, char *argv[])
     printf("Q(0)=%g + %g i, should be 0\n",
            crealf(optimal.data->data[0]), cimagf(optimal.data->data[0]));
   }
-  if ( fabs(crealf(optimal.data->data[0])) > STOCHASTICOPTIMALFILTERTESTC_TOL
-       || fabs(cimagf(optimal.data->data[0]))
+  if ( fabsf(crealf(optimal.data->data[0])) > STOCHASTICOPTIMALFILTERTESTC_TOL
+       || fabsf(cimagf(optimal.data->data[0]))
        > STOCHASTICOPTIMALFILTERTESTC_TOL )
   {
     printf("  FAIL: Valid data test #2\n");
@@ -1274,7 +1206,7 @@ int main(int argc, char *argv[])
     if (fabs(crealf(optimal.data->data[i])/crealf(optimal.data->data[1])
              - testNum)/testNum
         > STOCHASTICOPTIMALFILTERTESTC_TOL
-        || fabs(cimagf(optimal.data->data[i])/crealf(optimal.data->data[1]))
+        || fabsf(cimagf(optimal.data->data[i])/crealf(optimal.data->data[1]))
         > STOCHASTICOPTIMALFILTERTESTC_TOL)
     {
       printf("  FAIL: Valid data test #2\n");
